#undef PACKAGE
#undef VERSION

#undef HAVE_IPC_H
#undef HAVE_SHM_H
#undef HAVE_XSHM_H
#undef HAVE_SHM
#undef IPC_RMID_DEFERRED_RELEASE
#undef HAVE_LIBJPEG
#undef HAVE_LIBTIFF
#undef HAVE_LIBGIF
#undef HAVE_LIBPNG

#undef WITH_SYMBOL_UNDERSCORE

#undef HAVE_STDARGS
#undef USE_GMODULE
